"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransformGraphQLSchema = void 0;
const graphql_js_tree_1 = require("graphql-js-tree");
const getOperations = (tree) => {
    const query = tree.nodes.find((n) => { var _a; return (_a = n.type.operations) === null || _a === void 0 ? void 0 : _a.includes(graphql_js_tree_1.OperationType.query); });
    const mutation = tree.nodes.find((n) => { var _a; return (_a = n.type.operations) === null || _a === void 0 ? void 0 : _a.includes(graphql_js_tree_1.OperationType.mutation); });
    const subscription = tree.nodes.find((n) => { var _a; return (_a = n.type.operations) === null || _a === void 0 ? void 0 : _a.includes(graphql_js_tree_1.OperationType.subscription); });
    return {
        [graphql_js_tree_1.OperationType.query]: query,
        [graphql_js_tree_1.OperationType.mutation]: mutation,
        [graphql_js_tree_1.OperationType.subscription]: subscription,
    };
};
const TransformGraphQLSchema = ({ schema, transformers }) => {
    const initialTree = graphql_js_tree_1.Parser.parse(schema);
    const addSchema = [];
    transformers.forEach((transformer) => {
        const { nodes } = initialTree;
        const checkNode = (n) => {
            var _a;
            if ((_a = n.directives) === null || _a === void 0 ? void 0 : _a.find((d) => d.name === transformer.directiveName)) {
                addSchema.push(transformer.transformer({
                    tree: initialTree,
                    operations: getOperations(initialTree),
                    directiveName: transformer.directiveName,
                    field: n,
                    schema,
                }));
            }
            if (n.args) {
                n.args.forEach((a) => checkNode(a));
            }
        };
        nodes.forEach(checkNode);
    });
    const joinedSchemas = addSchema.join('\n').concat(schema);
    return graphql_js_tree_1.TreeToGraphQL.parse(graphql_js_tree_1.Parser.parseAddExtensions(joinedSchemas));
};
exports.TransformGraphQLSchema = TransformGraphQLSchema;
//# sourceMappingURL=index.js.map